@@ -6,6 +6,7 @@ __date__ ="$06/03/2011 00:40:36$"
 
 from PyQt4 import QtCore, QtGui, QtMaemo5
 import sys
+import os
 import pexpect
 import threading
 from graph import Graph
@@ -17,16 +18,24 @@ EVT_SMS="""RTCOM_EL_EVENTTYPE_SMS_MESSAGE"""
 EVT_CALL="""RTCOM_EL_EVENTTYPE_CALL"""
 EVT_CALL_MISS="""RTCOM_EL_EVENTTYPE_CALL_MISSED"""
 EVT_CALL_VOICEMAIL="""RTCOM_EL_EVENTTYPE_CALL_VOICEMAIL"""
+CONFIG_DIR="/home/user/.smscounter"
+CONFIG_FILE=CONFIG_DIR+"/options.cfg"
+
 def getSQL(sqlstr):
     #print sqlstr
     sql=pexpect.spawn("sqlite3",[DB_FILE,sqlstr])
     res=sql.readline()
     sql.sendeof()
     return res
+
+def getEventType(evt_type):
+    return """select id from EventTypes where name=\""""+evt_type+"""\""""
+
 def getSQLTot(evt_type):
-    sql="""select count(id) from Events where event_type_id=(select id from EventTypes where name=\""""
-    sql+=evt_type+"""\")"""
+    sql="""select count(id) from Events where event_type_id=("""
+    sql+=getEventType(evt_type)+""")"""
     return sql
+
 def getDateFilter(date,greater):
     res=""
     if date!=None:
@@ -41,9 +50,11 @@ def getDateFilter(date,greater):
 def getSentSMS(d1=None,d2=None):
     sqlstr=getSQLTot(EVT_SMS)+getDateFilter(d1,True)+getDateFilter(d2,False)+ """ AND outgoing=1"""
     return int(getSQL(sqlstr))
+
 def getReceivedSMS(d1=None,d2=None):
     sqlstr=getSQLTot(EVT_SMS)+getDateFilter(d1,True)+getDateFilter(d2,False) + """   AND outgoing=0"""
     return int(getSQL(sqlstr))
+
 def getSpamSMS(d1=None,d2=None):
     sqlstr=getSQLTot(EVT_SMS)+ getDateFilter(d1,True)+getDateFilter(d2,False)+ """ AND length(remote_uid)<=5"""
     return int(getSQL(sqlstr))
@@ -51,26 +62,76 @@ def getSpamSMS(d1=None,d2=None):
 def getMadeCalls(d1=None,d2=None):
     sqlstr=getSQLTot(EVT_CALL)+getDateFilter(d1,True)+getDateFilter(d2,False)+ """ AND outgoing=1"""
     return int(getSQL(sqlstr))
+
+def getMadeCallsDuration(d1=None,d2=None):
+    sqlstr="""select sum(case when event_type_id=("""+getEventType(EVT_CALL)+")"+getDateFilter(d1,True)+getDateFilter(d2,False)+ """ AND outgoing=1 AND end_time!=0 then end_time-start_time else 0 end) from Events""" 
+    res=(getSQL(sqlstr))
+    return float(res)
+
 def getReceivedCalls(d1=None,d2=None):
     sqlstr=getSQLTot(EVT_CALL)+getDateFilter(d1,True)+getDateFilter(d2,False) + """   AND outgoing=0"""
     return int(getSQL(sqlstr))
+
+def getReceivedCallsDuration(d1=None,d2=None):
+    sqlstr="""select sum(case when event_type_id=("""+getEventType(EVT_CALL)+")"+getDateFilter(d1,True)+getDateFilter(d2,False)+ """ AND outgoing=0 AND end_time!=0 then end_time-start_time else 0 end) from Events"""
+    res=(getSQL(sqlstr))
+    return float(res)
+
 def getMissedCalls(d1=None,d2=None):
     sqlstr=getSQLTot(EVT_CALL_MISS)+getDateFilter(d1,True)+getDateFilter(d2,False) + """   AND outgoing=0"""
     return int(getSQL(sqlstr))
+
 def getMinDate():
     d=None
     sqlstr="""select min(storage_time) from Events;"""
     d=int(getSQL(sqlstr))
     d=datetime.fromtimestamp(d)
     return d
+
 def strDateToBD(dateStr):
     d=datetime.strptime(dateStr,"%d.%m.%Y")
     d=d.replace(hour=0,minute=0,second=0)
     d1=int(mktime(d.timetuple()))
     return d1
+
 def datetimeToBD(dt):
     return int(mktime(dt.timetuple()))
 
+def timeFormat(secs):
+    res=""
+    res+="%02d:"%(secs//3600)
+    secs=secs%3600
+    res+="%02d:%02d"%(secs//60,secs%60)
+    return res
+
+class ConfigData(object):
+    sms_cost=0
+    call_minute_cost=0
+
+    @staticmethod
+    def save():
+        if not os.path.exists(CONFIG_DIR):
+            os.makedirs(CONFIG_DIR)
+        f=open(CONFIG_FILE,"w")
+        f.write("SMSCost="+str(ConfigData.sms_cost)+"\n")
+        f.write("CallCost="+str(ConfigData.call_minute_cost))
+    @staticmethod
+    def load():
+        if os.path.exists(CONFIG_FILE):
+            f=open(CONFIG_FILE,"r")
+            while True:
+                line=f.readline()
+                if not line: break
+                line=line.split("=")
+                if len(line)>=2:
+                    try:
+                        if line[0]=="SMSCost":
+                            ConfigData.sms_cost=float(line[1])
+                        elif line[0]=="CallCost":
+                            ConfigData.call_minute_cost=float(line[1])
+                    except ex:
+                        print ex
+                        
 class About(object):
     def setupUi(self, Form):
         Form.setObjectName("About")
@@ -92,7 +153,7 @@ class About(object):
 "p, li { white-space: pre-wrap; }\n"
 "</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
 "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:16pt; font-weight:600;\">SMS Counter</span></p>\n"
-"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">v0.1</span></p>\n"
+"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">v0.2</span></p>\n"
 "<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt; font-weight:600;\"></p>\n"
 "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><img src=\"/usr/share/icons/hicolor/64x64/hildon/smscounter.png\" /></p>\n"
 "<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt; font-weight:600;\"></p>\n"
@@ -116,8 +177,10 @@ class Data(object):
         self.rCalls=0
         self.sCalls=0
         self.mCalls=0
+	self.secRCalls=0
+	self.minSCalls=0
     def getPeriod(self):
-        res=""  
+        res=""
         if self.d1.year==self.d2.year and self.d1.month==self.d2.month and self.d1.day==1 and self.d2.day==calendar.monthrange(self.d2.year,self.d2.month)[1]:
             res=self.d1.strftime("%b %Y")
         else:
@@ -132,9 +195,58 @@ class Data(object):
         self.rCalls=getReceivedCalls(d1,d2)
         self.sCalls=getMadeCalls(d1,d2)
         self.mCalls=getMissedCalls(d1,d2)
-        
+        self.secRCalls=getReceivedCallsDuration(d1, d2)
+        self.secMCalls=getMadeCallsDuration(d1, d2)
+
+class ConfigDialog(QtGui.QDialog):
+    def __init__(self, parent):
+        QtGui.QDialog.__init__(self,parent)
+        self.setObjectName("Dialog")
+        self.resize(278, 109)
+        self.setModal(True)
+        self.gridLayout = QtGui.QGridLayout(self)
+        self.gridLayout.setObjectName("gridLayout")
+        self.buttonBox = QtGui.QDialogButtonBox(self)
+        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
+        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
+        self.buttonBox.setObjectName("buttonBox")
+        self.gridLayout.addWidget(self.buttonBox, 2, 1, 1, 1)
+        self.txtSMSCost = QtGui.QLineEdit(self)
+        self.txtSMSCost.setValidator(QtGui.QDoubleValidator(-1000.0,1000.0,2,self.txtSMSCost))
+        self.txtSMSCost.setObjectName("txtSMSCost")
+        self.gridLayout.addWidget(self.txtSMSCost, 0, 1, 1, 1)
+        self.label = QtGui.QLabel(self)
+        self.label.setObjectName("label")
+        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
+        self.label_2 = QtGui.QLabel(self)
+        self.label_2.setObjectName("label_2")
+        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
+        self.txtMinuteCost = QtGui.QLineEdit(self)
+        self.txtMinuteCost.setValidator(QtGui.QDoubleValidator(-1000.0,1000.0,2,self.txtMinuteCost))
+        self.txtMinuteCost.setObjectName("txtMinuteCost")
+        self.gridLayout.addWidget(self.txtMinuteCost, 1, 1, 1, 1)
+
+        self.retranslateUi(self)
+        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), self.accept)
+        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), self.reject)
+        QtCore.QMetaObject.connectSlotsByName(self)
+
+        self.txtSMSCost.setText(str(ConfigData.sms_cost))
+        self.txtMinuteCost.setText(str(ConfigData.call_minute_cost))
+    def retranslateUi(self, Dialog):
+        Dialog.setWindowTitle(QtGui.QApplication.translate("Dialog", "Configuration", None, QtGui.QApplication.UnicodeUTF8))
+        self.label.setText(QtGui.QApplication.translate("Dialog", "SMS Cost:", None, QtGui.QApplication.UnicodeUTF8))
+        self.label_2.setText(QtGui.QApplication.translate("Dialog", "Minute Cost:", None, QtGui.QApplication.UnicodeUTF8))
+
+    def accept(self):
+        ConfigData.sms_cost=float(self.txtSMSCost.text())
+        ConfigData.call_minute_cost=float(self.txtMinuteCost.text())
+        ConfigData.save()
+        QtGui.QDialog.accept(self)
+
 class MainWidget(object):
     def setupUi(self, Form):
+        ConfigData.load()
 	self.mw=Form
         Form.setObjectName("Form")
         Form.resize(421, 372)
@@ -144,7 +256,7 @@ class MainWidget(object):
         self.pnlTab.setObjectName("pnlTab")
         self.pnlTab.setTabPosition(QtGui.QTabWidget.West)
         self.tab = QtGui.QWidget()
-        self.tab.setObjectName("tab")        
+        self.tab.setObjectName("tab")
         self.gridLayout.addWidget(self.pnlTab, 1, 0, 1, 1)
         self.gridLayout_2 = QtGui.QGridLayout()
         self.gridLayout_2.setObjectName("gridLayout_2")
@@ -160,11 +272,13 @@ class MainWidget(object):
         self.fromDate.setObjectName("fromDate")
         self.btnFrom=QtMaemo5.QMaemo5ValueButton()
         self.btnFrom.setPickSelector(self.fromDate)
+        self.btnFrom.setEnabled(False)
         self.gridLayout_2.addWidget(self.btnFrom, 0, 1, 1, 1)
         self.toDate=QtMaemo5.QMaemo5DatePickSelector()
         self.toDate.setObjectName("toDate")
         self.btnTo=QtMaemo5.QMaemo5ValueButton()
         self.btnTo.setPickSelector(self.toDate)
+        self.btnTo.setEnabled(False)
         self.gridLayout_2.addWidget(self.btnTo, 0, 3, 1, 1)
         self.chkFrom = QtGui.QCheckBox(Form)
         sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
@@ -186,12 +300,18 @@ class MainWidget(object):
         self.gridLayout_2.addWidget(self.chkTo, 0, 2, 1, 1)
         self.gridLayout.addLayout(self.gridLayout_2, 0, 0, 1, 1)
 
-        self.dataWidget=DataWidget(Form)
-        self.pnlTab.addTab(self.dataWidget, "Totals")
+        self.smsWidget=SMSWidget(Form)
+        self.pnlTab.addTab(self.smsWidget, "SMS")
+        self.callsWidget=CallsWidget(Form)
+        self.pnlTab.addTab(self.callsWidget,"Calls")
+        
         self.dataGraph=DataGraph(Form)
         self.pnlTab.addTab(self.dataGraph, "Graph")
-	
+
 	self.menuBar = QtGui.QMenuBar(Form)
+        self.actionOptions = QtGui.QAction(Form)
+        self.actionOptions.setObjectName("actionOptions")
+        self.menuBar.addAction(self.actionOptions)
 	self.actionAbout = QtGui.QAction(Form)
         self.actionAbout.setObjectName("actionAbout")
         self.menuBar.addAction(self.actionAbout)
@@ -200,23 +320,35 @@ class MainWidget(object):
         self.menuBar.addAction(self.actionExit)
 
 	QtCore.QObject.connect(self.menuBar, QtCore.SIGNAL("triggered(QAction*)"), self.menuEvt)
-
+        
         self.retranslateUi(Form)
         self.pnlTab.setCurrentIndex(0)
         QtCore.QMetaObject.connectSlotsByName(Form)
         QtCore.QObject.connect(self.btnGo, QtCore.SIGNAL("clicked()"), self.btnGoAction)
-
+        QtCore.QObject.connect(self.chkFrom, QtCore.SIGNAL("stateChanged(int)"), self.chkFromSelected)
+        QtCore.QObject.connect(self.chkTo, QtCore.SIGNAL("stateChanged(int)"), self.chkToSelected)
+        
     def retranslateUi(self, Form):
         Form.setWindowTitle(QtGui.QApplication.translate("Form", "SMS Counter", None, QtGui.QApplication.UnicodeUTF8))
         self.btnFrom.setText("From")
         self.btnTo.setText("To")
+        self.actionOptions.setText("Options")
 	self.actionAbout.setText("About")
 	self.actionExit.setText("Exit")
         self.btnGo.setText(QtGui.QApplication.translate("Form", "Go!", None, QtGui.QApplication.UnicodeUTF8))
     
+    def chkFromSelected(self,v):
+        self.btnFrom.setEnabled(self.chkFrom.checkState())
+    
+    def chkToSelected(self,v):
+        self.btnTo.setEnabled(self.chkTo.checkState())
+    
     def menuEvt(self,qa):
         if qa==self.actionExit:
             self.mw.close()
+        elif qa==self.actionOptions:
+            ui = ConfigDialog(self.mw)
+            ui.show()
         elif qa==self.actionAbout:
             Form = QtGui.QDialog(self.mw)
             ui = About()
@@ -229,14 +361,17 @@ class MainWidget(object):
         if self.chkFrom.checkState():
             d1=strDateToBD(str(self.fromDate.currentDate().toString("dd.MM.yyyy")))
         return d1
+    
     def getTo(self):
         d1=None
         if self.chkTo.checkState():
             d1=strDateToBD(str(self.toDate.currentDate().toString("dd.MM.yyyy")))
         return d1
+    
     def btnGoAction(self):
         t=QueryThread(self)
         t.start()
+    
     def query(self):
 	self.btnGo.setEnabled(False)
 	self.btnGo.setText("Wait")
@@ -273,76 +408,63 @@ class MainWidget(object):
         dat.d2=d2
         dat.fillData()
         data.append(dat)
-        self.dataWidget.query(data)
+        self.smsWidget.query(data)
+        self.callsWidget.query(data)
         self.dataGraph.query(data)
         self.btnGo.setText("Go!")
 	self.pnlTab.setEnabled(True)
 	self.btnGo.setEnabled(True)
-class DataWidget(QtGui.QWidget):
+        
+class SMSWidget(QtGui.QWidget):
     def __init__(self, parent=None):
         QtGui.QWidget.__init__(self, parent)
+        f=self.font()
+        f.setBold(True)
         self.gridLayout = QtGui.QGridLayout(self)
         self.gridLayout.setObjectName("gridLayout")
-        
+
         self.lblTotSMS = QtGui.QLabel(self)
         self.lblTotSMS.setObjectName("lblTotSMS")
+        self.lblTotSMS.setFont(f)
         self.gridLayout.addWidget(self.lblTotSMS, 3, 0, 1, -1)
+        
         self.lblSentSMS = QtGui.QLabel(self)
         self.lblSentSMS.setObjectName("lblSentSMS")
-        self.gridLayout.addWidget(self.lblSentSMS, 2, 0, 1, -1)
+        self.gridLayout.addWidget(self.lblSentSMS, 2, 0, 1, 1)
+        
+        self.lblSMSCost = QtGui.QLabel(self)
+        self.lblSMSCost.setObjectName("lblSMSCost")
+        self.gridLayout.addWidget(self.lblSMSCost, 2, 1, 1, 1)
+        
         self.lblReceivedSMS = QtGui.QLabel(self)
         self.lblReceivedSMS.setObjectName("lblReceivedSMS")
         self.gridLayout.addWidget(self.lblReceivedSMS, 1, 0, 1, 1)
+        
         self.lblSpamSMS = QtGui.QLabel(self)
         self.lblSpamSMS.setObjectName("lblSpamSMS")
         self.gridLayout.addWidget(self.lblSpamSMS, 1, 1, 1, 1)
 
-	self.lblTotCalls = QtGui.QLabel(self)
-        self.lblTotCalls.setObjectName("lblTotCalls")
-        self.gridLayout.addWidget(self.lblTotCalls, 7, 0, 1, -1)
-        self.lblMadeCalls = QtGui.QLabel(self)
-        self.lblMadeCalls.setObjectName("lblMadeCalls")
-        self.gridLayout.addWidget(self.lblMadeCalls, 6, 0, 1,-1)
-        self.lblMissedCalls = QtGui.QLabel(self)
-	self.lblMissedCalls.setObjectName("lblMissedCalls")
-        self.gridLayout.addWidget(self.lblMissedCalls, 5, 0, 1, -1)
-	self.lblReceivedCalls = QtGui.QLabel(self)
-        self.lblReceivedCalls.setObjectName("lblReceivedCalls")
-        self.gridLayout.addWidget(self.lblReceivedCalls, 4, 0, 1, -1)
-	
         self.retranslateUi()
-        
+
     def retranslateUi(self):
         self.lblTotSMS.setText("Total SMS:")
         self.lblSentSMS.setText("Sent SMS:")
+        self.lblSMSCost.setText("Cost:")
         self.lblReceivedSMS.setText("Received SMS:")
         self.lblSpamSMS.setText("Spam:")
-	self.lblTotCalls.setText("Total Calls:")
-        self.lblMadeCalls.setText("Calls made:")
-        self.lblReceivedCalls.setText("Calls received:")
-	self.lblMissedCalls.setText("Calls missed:")
-    
     
     def query(self,data):
         receivedS=0
         sentS=0
 	totS=0
         Spam=0
-        receivedC=0
-        sentC=0
-	totC=0
-        missedC=0
         for dat in data:
             receivedS+=dat.rSms
             sentS+=dat.sSms
             Spam+=dat.cSms
-            receivedC+=dat.rCalls
-            sentC+=dat.sCalls
-            missedC+=dat.mCalls
         totS=receivedS+sentS
-        totC=receivedC+sentC+missedC
-        
-            
+        costS=round(sentS*ConfigData.sms_cost,2)
+
         rr=0
         if receivedS>0:
             rr=round(float(Spam)/receivedS*100,2)
@@ -359,8 +481,80 @@ class DataWidget(QtGui.QWidget):
         self.lblTotSMS.setText("Total SMS: "+totS)
         self.lblReceivedSMS.setText("Received SMS: "+receivedS)
         self.lblSentSMS.setText("Sent SMS: "+sentS)
+        self.lblSMSCost.setText("Cost: "+str(costS))
         self.lblSpamSMS.setText("Spam: "+Spam)
-	
+
+class CallsWidget(QtGui.QWidget):
+    def __init__(self, parent=None):
+        QtGui.QWidget.__init__(self, parent)
+        
+        self.gridLayout = QtGui.QGridLayout(self)
+        self.gridLayout.setObjectName("gridLayout")
+
+	self.lblReceivedCalls = QtGui.QLabel(self)
+        self.lblReceivedCalls.setObjectName("lblReceivedCalls")
+        self.gridLayout.addWidget(self.lblReceivedCalls, 1, 0, 1, 1)
+        
+        self.lblRCallsDuration = QtGui.QLabel(self)
+        self.lblRCallsDuration.setObjectName("lblRCallsDuration")
+        self.gridLayout.addWidget(self.lblRCallsDuration, 1, 1, 1, 1)
+        
+        self.lblMadeCalls = QtGui.QLabel(self)
+        self.lblMadeCalls.setObjectName("lblMadeCalls")
+        self.gridLayout.addWidget(self.lblMadeCalls, 2, 0, 1,1)
+        
+        self.lblMCallsDuration = QtGui.QLabel(self)
+        self.lblMCallsDuration.setObjectName("lblMCallsDuration")
+        self.gridLayout.addWidget(self.lblMCallsDuration, 2, 1, 1,1)
+        
+        self.lblMCallsCost = QtGui.QLabel(self)
+        self.lblMCallsCost.setObjectName("lblMCallsCost")
+        self.gridLayout.addWidget(self.lblMCallsCost, 3, 1, 1,1)
+        
+        self.lblMissedCalls = QtGui.QLabel(self)
+	self.lblMissedCalls.setObjectName("lblMissedCalls")
+        self.gridLayout.addWidget(self.lblMissedCalls, 4, 0, 1, -1)
+        
+        f=self.font()
+        f.setBold(True)
+        self.lblTotCalls = QtGui.QLabel(self)
+        self.lblTotCalls.setObjectName("lblTotCalls")
+        self.lblTotCalls.setFont(f);
+        self.gridLayout.addWidget(self.lblTotCalls, 5, 0, 1, 1)
+        
+        self.lblTotMinutes = QtGui.QLabel(self)
+        self.lblTotMinutes.setObjectName("lblTotMinutes")
+        self.lblTotMinutes.setFont(QtGui.QFont("Sans Serif",20,QtGui.QFont.Bold));
+        self.lblTotMinutes.setFont(f)
+        self.gridLayout.addWidget(self.lblTotMinutes, 5, 1, 1, 1)
+
+        self.retranslateUi()
+
+    def retranslateUi(self):
+	self.lblTotCalls.setText("Total:")
+        self.lblTotMinutes.setText("Total duration:")
+        self.lblMadeCalls.setText("Made:")
+        self.lblMCallsDuration.setText("Duration:")
+        self.lblMCallsCost.setText("Cost:")
+        self.lblReceivedCalls.setText("Received:")
+        self.lblRCallsDuration.setText("Duration:")
+	self.lblMissedCalls.setText("Missed:")
+
+    def query(self,data):
+        receivedC=0
+        secRCalls=0
+        secMCalls=0
+        sentC=0
+	totC=0
+        missedC=0
+        for dat in data:
+            receivedC+=dat.rCalls
+            sentC+=dat.sCalls
+            missedC+=dat.mCalls        
+            secRCalls+=dat.secRCalls
+            secMCalls+=dat.secMCalls
+        totC=receivedC+sentC+missedC
+
 	rr=0
         if totC>0:
             rr=round(float(receivedC)/totC*100,2)
@@ -374,11 +568,16 @@ class DataWidget(QtGui.QWidget):
             rr=round(float(sentC)/totC*100,2)
         sentC=str(sentC)+" ("+str(rr)+"%)"
         totC=str(totC)
-	self.lblTotCalls.setText("Total Calls: "+totC)
-        self.lblReceivedCalls.setText("Calls received: "+receivedC)
-        self.lblMadeCalls.setText("Calls made: "+sentC)
-	self.lblMissedCalls.setText("Calls missed: "+missedC)
-
+	self.lblTotCalls.setText("Total: "+totC)
+        self.lblReceivedCalls.setText("Received: "+receivedC)
+        rr=""
+        self.lblRCallsDuration.setText("Duration: "+timeFormat(secRCalls))
+        self.lblMadeCalls.setText("Made: "+sentC)
+        self.lblMCallsDuration.setText("Duration: "+timeFormat(secMCalls))
+        self.lblTotMinutes.setText("Total duration: "+timeFormat(secRCalls+secMCalls))
+        self.lblMCallsCost.setText("Cost: "+str(secMCalls/60*ConfigData.call_minute_cost))
+	self.lblMissedCalls.setText("Missed: "+missedC)
+        
 class DataGraph(QtGui.QWidget):
     def __init__(self, parent=None):
         QtGui.QWidget.__init__(self, parent)
